==> zio-aws-cloudfront_2.13-5.17.121.2-sources.jar: zio/aws/cloudfront/model/FunctionAssociations.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cloudfront.model.primitives.Integer
import scala.jdk.CollectionConverters._
final case class FunctionAssociations(
    quantity: Integer,
    items: Option[Iterable[zio.aws.cloudfront.model.FunctionAssociation]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.FunctionAssociations = {
    import FunctionAssociations.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.FunctionAssociations
      .builder()
      .quantity(Integer.unwrap(quantity): java.lang.Integer)
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.FunctionAssociations.ReadOnly =
    zio.aws.cloudfront.model.FunctionAssociations.wrap(buildAwsValue())
}
object FunctionAssociations {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.FunctionAssociations
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.FunctionAssociations =
      zio.aws.cloudfront.model.FunctionAssociations(
        quantity,
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def quantity: Integer
    def items
        : Option[List[zio.aws.cloudfront.model.FunctionAssociation.ReadOnly]]
    def getQuantity: ZIO[Any, Nothing, Integer] = ZIO.succeed(quantity)
    def getItems: ZIO[Any, AwsError, List[
      zio.aws.cloudfront.model.FunctionAssociation.ReadOnly
    ]] = AwsError.unwrapOptionField("items", items)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.FunctionAssociations
  ) extends zio.aws.cloudfront.model.FunctionAssociations.ReadOnly {
    override val quantity: Integer =
      zio.aws.cloudfront.model.primitives.Integer(impl.quantity())
    override val items
        : Option[List[zio.aws.cloudfront.model.FunctionAssociation.ReadOnly]] =
      scala
        .Option(impl.items())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.cloudfront.model.FunctionAssociation.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.FunctionAssociations
  ): zio.aws.cloudfront.model.FunctionAssociations.ReadOnly = new Wrapper(impl)
}

==> zio-aws-cloudfront_2.13-5.17.151.1-sources.jar: zio/aws/cloudfront/model/FunctionAssociations.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cloudfront.model.primitives.Integer
import scala.jdk.CollectionConverters._
final case class FunctionAssociations(
    quantity: Integer,
    items: Option[Iterable[zio.aws.cloudfront.model.FunctionAssociation]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.FunctionAssociations = {
    import FunctionAssociations.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.FunctionAssociations
      .builder()
      .quantity(quantity: java.lang.Integer)
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.FunctionAssociations.ReadOnly =
    zio.aws.cloudfront.model.FunctionAssociations.wrap(buildAwsValue())
}
object FunctionAssociations {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.FunctionAssociations
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.FunctionAssociations =
      zio.aws.cloudfront.model.FunctionAssociations(
        quantity,
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def quantity: Integer
    def items
        : Option[List[zio.aws.cloudfront.model.FunctionAssociation.ReadOnly]]
    def getQuantity: ZIO[Any, Nothing, Integer] = ZIO.succeed(quantity)
    def getItems: ZIO[Any, AwsError, List[
      zio.aws.cloudfront.model.FunctionAssociation.ReadOnly
    ]] = AwsError.unwrapOptionField("items", items)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.FunctionAssociations
  ) extends zio.aws.cloudfront.model.FunctionAssociations.ReadOnly {
    override val quantity: Integer = impl.quantity(): Integer
    override val items
        : Option[List[zio.aws.cloudfront.model.FunctionAssociation.ReadOnly]] =
      scala
        .Option(impl.items())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.cloudfront.model.FunctionAssociation.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.FunctionAssociations
  ): zio.aws.cloudfront.model.FunctionAssociations.ReadOnly = new Wrapper(impl)
}
